==> 2.0.4.tar.gz: android/src/main/kotlin/com/fireworksdk/bridge/flutter/utils/FWEventUtils.kt <==
package com.fireworksdk.bridge.flutter.utils

import com.firework.common.product.Product
import com.fireworksdk.bridge.models.*
import com.fireworksdk.bridge.models.enums.FWEventName
import com.fireworksdk.bridge.models.enums.FWFeedViewEventName
import com.fireworksdk.bridge.models.enums.FWSDKInitSubEventName
import com.fireworksdk.bridge.models.enums.FWStoryBlockEventName
import com.fireworksdk.bridge.models.enums.FWVideoShoppingEventName
import com.fireworksdk.bridge.utils.FWLogUtils
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.Result

object FWEventUtils {

  fun sendInitSuccessEvent(methodChannel: MethodChannel?) {
    sendEvent(methodChannel, FWEventName.SDKIni.rawValue, HashMap<String, Any>())
  }

  fun sendInitFailedEvent(methodChannel: MethodChannel?, reason: String) {
    val err = mapOf(
      "error" to mapOf(
        "name" to FWSDKInitSubEventName.InitFailed.rawValue,
        "reason" to reason
      )
    )
    FWLogUtils.e { err.toString() }
    sendEvent(methodChannel, FWEventName.SDKIni.rawValue, err)
  }

  fun sendVideoFeedClickEvent(methodChannel: MethodChannel?, info: FWVideoFeedItemDetailsModel) {
    val eventMap = mapOf(
      "info" to mapOf(
        "index" to (info.index ?: 0),
        "id" to info.id,
        "duration" to (info.duration ?: 0),
        "source" to (info.source),
        "title" to (info.title),
        "playlistGroup" to (info.playlistGroup),
        "playlist" to (info.playlist),
        "channel" to (info.channel),
        "dynamicContentParameters" to (info.dynamicContentParameters),
      )
    )
    sendEvent(methodChannel, FWEventName.VideoFeedClick.rawValue, eventMap)
  }

  fun sendCustomCTAClickEvent(methodChannel: MethodChannel?, url: String?) {
    sendEvent(methodChannel, FWEventName.CustomCTAClick.rawValue, mapOf("url" to url))
  }

  fun sendVideoPlaybackEvent(
    methodChannel: MethodChannel?,
    eventName: String,
    info: FWVideoPlaybackDetails?
  ) {
    val eventMap = HashMap<String, Any?>()
    eventMap["eventName"] = eventName

    val contentMap = HashMap<String, Any?>()
    if (!info?.id.isNullOrBlank()) {
      contentMap["videoId"] = info?.id
    }
    if (info?.duration != null) {
      contentMap["duration"] = info.duration.toDouble()
    }
    if (!info?.caption.isNullOrBlank()) {
      contentMap["caption"] = info?.caption
    }
    if (!info?.badge.isNullOrBlank() && !info?.badge.equals("null")) {
      contentMap["badge"] = info?.badge
    }
    if (info?.playerWidth != null || info?.playerHeight != null) {
      val playerSizeMap = HashMap<String, Any?>()
      if (info.playerWidth != null) {
        playerSizeMap["width"] = info.playerWidth
      }
      if (info.playerHeight != null) {
        playerSizeMap["height"] = info.playerHeight
      }
      contentMap["playerSize"] = playerSizeMap
    }
    if (info?.hasCta != null) {
      contentMap["hasCTA"] = info.hasCta
    }
    if (info?.progress != null) {
      contentMap["progress"] = info.progress
    }
    if (!info?.actionUrl.isNullOrBlank()) {
      contentMap["ctaActionURL"] = info?.actionUrl
    }
    eventMap["info"] = contentMap

    sendEvent(methodChannel, FWEventName.VideoPlayback.rawValue, eventMap)
  }

  fun sendVideoFeedLoadSuccessEvent(methodChannel: MethodChannel?) {
    sendEvent(methodChannel, FWFeedViewEventName.VideoFeedLoadFinished.rawValue, null)
  }

  fun sendVideoFeedLoadFailedEvent(methodChannel: MethodChannel?, name: String, reason: String) {
    val err = mapOf("name" to name, "reason" to reason)
    FWLogUtils.e { err.toString() }
    sendEvent(methodChannel, FWFeedViewEventName.VideoFeedLoadFinished.rawValue, err)
  }

  fun sendShoppingCtaButtonClickEvent(
    methodChannel: MethodChannel?,
    productId: String?,
    unitId: String?,
    url: String?,
    callback: Result? = null
  ) {
    val eventMap = HashMap<String, Any?>()
    eventMap["productId"] = productId
    eventMap["unitId"] = unitId
    eventMap["url"] = url
    sendEvent(methodChannel, FWVideoShoppingEventName.CtaButtonClick.rawValue, eventMap, callback)
  }

  fun sendClickCartIconEvent(methodChannel: MethodChannel?) {
    val eventMap = HashMap<String, Any?>()
    sendEvent(methodChannel, FWVideoShoppingEventName.ClickCartIcon.rawValue, eventMap)
  }

  fun sendUpdateProductsDetailsEvent(
    methodChannel: MethodChannel?,
    products: List<Product>?,
    callback: Result? = null
  ) {
    val eventMap = HashMap<String, Any?>()

    val productArray = ArrayList<String?>()
    if (!products.isNullOrEmpty()) {
      for (product in products) {
        productArray.add(product.id)
      }
    }

    eventMap["productIds"] = productArray
    sendEvent(
      methodChannel,
      FWVideoShoppingEventName.UpdateProductDetails.rawValue,
      eventMap,
      callback
    )
  }

  fun sendCustomLinkButtonClickEvent(methodChannel: MethodChannel?, url: String?, productId: String?, unitId: String?) {
    val eventMap = HashMap<String, Any?>()
    eventMap["url"] = url?:""
    eventMap["productId"] = productId
    eventMap["unitId"] = unitId
    sendEvent(methodChannel, FWVideoShoppingEventName.CustomLinkButtonClick.rawValue, eventMap)
  }

  private fun sendEvent(
    methodChannel: MethodChannel?,
    eventName: String,
    eventMap: Map<String, Any?>?,
    callback: Result? = null
  ) {
    methodChannel?.invokeMethod(eventName, eventMap, callback)
  }

  // live stream
  fun sendLiveStreamEvent(
    methodChannel: MethodChannel?,
    eventName: String,
    info: FWLiveStreamEventDetailsModel?
  ) {
    val eventMap = HashMap<String, Any?>()
    eventMap["eventName"] = eventName

    val contentMap = HashMap<String, Any?>()
    if (!info?.id.isNullOrBlank()) {
      contentMap["id"] = info?.id
    }
    eventMap["info"] = contentMap

    sendEvent(methodChannel, FWEventName.LiveStream.rawValue, eventMap)
  }

  fun sendLiveStreamChatEvent(
    methodChannel: MethodChannel?,
    eventName: String,
    message: FWLiveStreamMessageDetailsModel?,
    liveStream: FWLiveStreamEventDetailsModel?
  ) {
    val eventMap = HashMap<String, Any?>()
    eventMap["eventName"] = eventName

    // chat map
    val chatMap = HashMap<String, Any?>()
    if (!message?.messageId.isNullOrBlank()) {
      chatMap["messageId"] = message?.messageId
    }
    if (!message?.username.isNullOrBlank()) {
      chatMap["username"] = message?.username
    }
    if (!message?.text.isNullOrBlank()) {
      chatMap["text"] = message?.text
    }
    eventMap["chat"] = chatMap

    // live stream map
    val liveStreamMap = HashMap<String, Any?>()
    if (!liveStream?.id.isNullOrBlank()) {
      liveStreamMap["id"] = liveStream?.id
    }
    eventMap["liveStream"] = liveStreamMap

    sendEvent(methodChannel, FWEventName.LiveStreamChat.rawValue, eventMap)
  }

  fun sendStoryBlockLoadSuccessEvent(methodChannel: MethodChannel?) {
    sendEvent(methodChannel, FWStoryBlockEventName.StoryBlockLoadFinished.rawValue, null)
  }

  fun sendStoryBlockLoadFailedEvent(methodChannel: MethodChannel?, name: String, reason: String) {
    val err = mapOf("name" to name, "reason" to reason)
    FWLogUtils.e { err.toString() }
    sendEvent(methodChannel, FWStoryBlockEventName.StoryBlockLoadFinished.rawValue, err)
  }

  fun sendStoryBlockFullScreenStateChangeEvent(methodChannel: MethodChannel?, isFullScreen: Boolean) {
    val eventMap = HashMap<String, Any?>()
    eventMap["isFullScreen"] = isFullScreen
    sendEvent(methodChannel, FWStoryBlockEventName.StoryBlockFullScreenStateChanged.rawValue, eventMap)
  }
}

==> 2.4.0.tar.gz: android/src/main/kotlin/com/fireworksdk/bridge/flutter/utils/FWEventUtils.kt <==
package com.fireworksdk.bridge.flutter.utils

import com.firework.common.product.Product
import com.fireworksdk.bridge.models.*
import com.fireworksdk.bridge.models.enums.FWEventName
import com.fireworksdk.bridge.models.enums.FWFeedViewEventName
import com.fireworksdk.bridge.models.enums.FWSDKInitSubEventName
import com.fireworksdk.bridge.models.enums.FWStoryBlockEventName
import com.fireworksdk.bridge.models.enums.FWVideoShoppingEventName
import com.fireworksdk.bridge.utils.FWLogUtils
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.Result

object FWEventUtils {

  fun sendInitSuccessEvent(methodChannel: MethodChannel?) {
    sendEvent(methodChannel, FWEventName.SDKIni.rawValue, HashMap<String, Any>())
  }

  fun sendInitFailedEvent(methodChannel: MethodChannel?, reason: String) {
    val err = mapOf(
      "error" to mapOf(
        "name" to FWSDKInitSubEventName.InitFailed.rawValue,
        "reason" to reason
      )
    )
    FWLogUtils.e { err.toString() }
    sendEvent(methodChannel, FWEventName.SDKIni.rawValue, err)
  }

  fun sendVideoFeedClickEvent(methodChannel: MethodChannel?, info: FWVideoFeedItemDetailsModel) {
    val eventMap = mapOf(
      "info" to mapOf(
        "index" to (info.index ?: 0),
        "id" to info.id,
        "duration" to (info.duration ?: 0),
        "source" to (info.source),
        "title" to (info.title),
        "playlistGroup" to (info.playlistGroup),
        "playlist" to (info.playlist),
        "channel" to (info.channel),
        "dynamicContentParameters" to (info.dynamicContentParameters),
      )
    )
    sendEvent(methodChannel, FWEventName.VideoFeedClick.rawValue, eventMap)
  }

  fun sendCustomCTAClickEvent(methodChannel: MethodChannel?, url: String?) {
    sendEvent(methodChannel, FWEventName.CustomCTAClick.rawValue, mapOf("url" to url))
  }

  fun sendVideoPlaybackEvent(
    methodChannel: MethodChannel?,
    eventName: String,
    info: FWVideoPlaybackDetails?
  ) {
    val eventMap = HashMap<String, Any?>()
    eventMap["eventName"] = eventName

    val contentMap = HashMap<String, Any?>()
    if (!info?.id.isNullOrBlank()) {
      contentMap["videoId"] = info?.id
    }
    if (info?.duration != null) {
      contentMap["duration"] = info.duration.toDouble()
    }
    if (!info?.caption.isNullOrBlank()) {
      contentMap["caption"] = info?.caption
    }
    if (!info?.badge.isNullOrBlank() && !info?.badge.equals("null")) {
      contentMap["badge"] = info?.badge
    }
    if (info?.playerWidth != null || info?.playerHeight != null) {
      val playerSizeMap = HashMap<String, Any?>()
      if (info.playerWidth != null) {
        playerSizeMap["width"] = info.playerWidth
      }
      if (info.playerHeight != null) {
        playerSizeMap["height"] = info.playerHeight
      }
      contentMap["playerSize"] = playerSizeMap
    }
    if (info?.hasCta != null) {
      contentMap["hasCTA"] = info.hasCta
    }
    if (info?.progress != null) {
      contentMap["progress"] = info.progress
    }
    if (!info?.actionUrl.isNullOrBlank()) {
      contentMap["ctaActionURL"] = info?.actionUrl
    }
    eventMap["info"] = contentMap

    sendEvent(methodChannel, FWEventName.VideoPlayback.rawValue, eventMap)
  }

  fun sendVideoFeedLoadSuccessEvent(methodChannel: MethodChannel?) {
    sendEvent(methodChannel, FWFeedViewEventName.VideoFeedLoadFinished.rawValue, null)
  }

  fun sendVideoFeedEmptyEvent(methodChannel: MethodChannel?) {
    sendEvent(methodChannel, FWFeedViewEventName.VideoFeedEmpty.rawValue, null)
  }

  fun sendVideoFeedLoadFailedEvent(methodChannel: MethodChannel?, name: String?, reason: String?, action: String) {
    val err = mapOf("name" to (name?:"VideoFeedLoadFailed"), "reason" to (reason?:"VideoFeedLoadFailed"), "action" to action)
    FWLogUtils.e { err.toString() }
    sendEvent(methodChannel, FWFeedViewEventName.VideoFeedLoadFinished.rawValue, err)
  }

  fun sendShoppingCtaButtonClickEvent(
    methodChannel: MethodChannel?,
    productId: String?,
    unitId: String?,
    url: String?,
    callback: Result? = null
  ) {
    val eventMap = HashMap<String, Any?>()
    eventMap["productId"] = productId
    eventMap["unitId"] = unitId
    eventMap["url"] = url
    sendEvent(methodChannel, FWVideoShoppingEventName.CtaButtonClick.rawValue, eventMap, callback)
  }

  fun sendClickCartIconEvent(methodChannel: MethodChannel?) {
    val eventMap = HashMap<String, Any?>()
    sendEvent(methodChannel, FWVideoShoppingEventName.ClickCartIcon.rawValue, eventMap)
  }

  fun sendUpdateProductsDetailsEvent(
    methodChannel: MethodChannel?,
    products: List<Product>?,
    callback: Result? = null
  ) {
    val eventMap = HashMap<String, Any?>()

    val productArray = ArrayList<String?>()
    if (!products.isNullOrEmpty()) {
      for (product in products) {
        productArray.add(product.id)
      }
    }

    eventMap["productIds"] = productArray
    sendEvent(
      methodChannel,
      FWVideoShoppingEventName.UpdateProductDetails.rawValue,
      eventMap,
      callback
    )
  }

  fun sendProductCardClickEvent(methodChannel: MethodChannel?, url: String?, productId: String?, unitId: String?) {
    val eventMap = HashMap<String, Any?>()
    eventMap["url"] = url?:""
    eventMap["productId"] = productId
    eventMap["unitId"] = unitId
    sendEvent(methodChannel, FWVideoShoppingEventName.CustomProductCardTap.rawValue, eventMap)
  }

  fun sendCustomLinkButtonClickEvent(methodChannel: MethodChannel?, url: String?, productId: String?, unitId: String?) {
    val eventMap = HashMap<String, Any?>()
    eventMap["url"] = url?:""
    eventMap["productId"] = productId
    eventMap["unitId"] = unitId
    sendEvent(methodChannel, FWVideoShoppingEventName.CustomLinkButtonClick.rawValue, eventMap)
  }

  private fun sendEvent(
    methodChannel: MethodChannel?,
    eventName: String,
    eventMap: Map<String, Any?>?,
    callback: Result? = null
  ) {
    methodChannel?.invokeMethod(eventName, eventMap, callback)
  }

  // live stream
  fun sendLiveStreamEvent(
    methodChannel: MethodChannel?,
    eventName: String,
    info: FWLiveStreamEventDetailsModel?
  ) {
    val eventMap = HashMap<String, Any?>()
    eventMap["eventName"] = eventName

    val contentMap = HashMap<String, Any?>()
    if (!info?.id.isNullOrBlank()) {
      contentMap["id"] = info?.id
    }
    eventMap["info"] = contentMap

    sendEvent(methodChannel, FWEventName.LiveStream.rawValue, eventMap)
  }

  fun sendLiveStreamChatEvent(
    methodChannel: MethodChannel?,
    eventName: String,
    message: FWLiveStreamMessageDetailsModel?,
    liveStream: FWLiveStreamEventDetailsModel?
  ) {
    val eventMap = HashMap<String, Any?>()
    eventMap["eventName"] = eventName

    // chat map
    val chatMap = HashMap<String, Any?>()
    if (!message?.messageId.isNullOrBlank()) {
      chatMap["messageId"] = message?.messageId
    }
    if (!message?.username.isNullOrBlank()) {
      chatMap["username"] = message?.username
    }
    if (!message?.text.isNullOrBlank()) {
      chatMap["text"] = message?.text
    }
    eventMap["chat"] = chatMap

    // live stream map
    val liveStreamMap = HashMap<String, Any?>()
    if (!liveStream?.id.isNullOrBlank()) {
      liveStreamMap["id"] = liveStream?.id
    }
    eventMap["liveStream"] = liveStreamMap

    sendEvent(methodChannel, FWEventName.LiveStreamChat.rawValue, eventMap)
  }

  fun sendStoryBlockLoadSuccessEvent(methodChannel: MethodChannel?) {
    sendEvent(methodChannel, FWStoryBlockEventName.StoryBlockLoadFinished.rawValue, null)
  }

  fun sendStoryBlockEmptyEvent(methodChannel: MethodChannel?) {
    sendEvent(methodChannel, FWStoryBlockEventName.StoryBlockEmpty.rawValue, null)
  }

  fun sendStoryBlockLoadFailedEvent(methodChannel: MethodChannel?, name: String?, reason: String?) {
    val err = mapOf("name" to (name?:"StoryBlockLoadFailed"), "reason" to (reason?:"StoryBlockLoadFailed"))
    FWLogUtils.e { err.toString() }
    sendEvent(methodChannel, FWStoryBlockEventName.StoryBlockLoadFinished.rawValue, err)
  }

  fun sendStoryBlockFullScreenStateChangeEvent(methodChannel: MethodChannel?, isFullScreen: Boolean) {
    val eventMap = HashMap<String, Any?>()
    eventMap["isFullScreen"] = isFullScreen
    sendEvent(methodChannel, FWStoryBlockEventName.StoryBlockFullScreenStateChanged.rawValue, eventMap)
  }
}
